tokenizer\_tools.tagset.NER package
===================================

Submodules
----------

tokenizer\_tools.tagset.NER.BILUO module
----------------------------------------

.. automodule:: tokenizer_tools.tagset.NER.BILUO
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.tagset.NER.IOB module
--------------------------------------

.. automodule:: tokenizer_tools.tagset.NER.IOB
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.tagset.NER.base\_tagset module
-----------------------------------------------

.. automodule:: tokenizer_tools.tagset.NER.base_tagset
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tokenizer_tools.tagset.NER
   :members:
   :undoc-members:
   :show-inheritance:
